@@ -26,26 +26,6 @@ def safe_func(func):
     return func_wrapper
 
 
-def ip_bin_to_str(ip_num):
-    """
-    转换ip格式，从bin转为str
-    :param ip_num:
-    :return:
-    """
-    import socket
-    return socket.inet_ntoa(ip_num)
-
-
-def ip_str_to_bin(ip_str):
-    """
-    转化ip格式，从str转为bin
-    :param ip_str:
-    :return:
-    """
-    import socket
-    return socket.inet_aton(ip_str)
-
-
 def import_module_or_string(src):
     """
     按照模块导入或者字符串导入
